<?php

namespace Drupal\Tests\raven\Functional;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Tests\BrowserTestBase;
use PHPUnit\Framework\SkippedTestError;

/**
 * Tests Raven and CSP modules.
 *
 * @group raven
 * @requires modules csp
 */
class CspTest extends BrowserTestBase {

  use StringTranslationTrait;

  /**
   * Additional module to enable.
   */
  const MODULE = 'csp';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['raven'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // @fixme The following three lines can be removed if/when module is
    // restored as test dependency.
    if (!isset($this->container->get('extension.list.module')->reset()->getList()[static::MODULE])) {
      throw new SkippedTestError('Required Drupal module: ' . static::MODULE);
    }
    $this->container->get('module_installer')->install([static::MODULE]);
  }

  /**
   * Tests Sentry browser client configuration UI.
   */
  public function testRavenJavascriptConfig(): void {
    $admin_user = $this->drupalCreateUser([
      'administer csp configuration',
      'administer site configuration',
      'send javascript errors to sentry',
    ]);

    $this->drupalLogin($admin_user);

    $this->drupalGet('admin/config/development/logging');
    $this->submitForm([
      'raven[js][javascript_error_handler]' => TRUE,
      'raven[js][public_dsn]' => 'https://a@domain.test/1',
    ], $this->t('Save configuration'));

    $this->drupalGet('admin/config/system/csp');
    $this->submitForm([
      'report-only[reporting][handler]' => 'raven',
    ], $this->t('Save configuration'));

    $this->assertSession()->responseHeaderEquals('Content-Security-Policy-Report-Only', "object-src 'none'; script-src 'self'; style-src 'self'; frame-ancestors 'self'; report-uri https://domain.test/api/1/security/?sentry_key=a");

    $this->drupalGet('admin/config/system/csp');
    $this->submitForm([
      'report-only[directives][connect-src][enable]' => TRUE,
      'report-only[directives][connect-src][base]' => 'self',
    ], $this->t('Save configuration'));

    $this->assertSession()->responseHeaderEquals('Content-Security-Policy-Report-Only', "connect-src 'self' https://domain.test/api/1/store/ https://domain.test/api/1/envelope/; object-src 'none'; script-src 'self'; style-src 'self'; frame-ancestors 'self'; report-uri https://domain.test/api/1/security/?sentry_key=a");
  }

}
