<?php

namespace Drupal\Tests\raven\Functional;

use Drupal\Core\StringTranslation\StringTranslationTrait;
use Drupal\Tests\BrowserTestBase;
use PHPUnit\Framework\SkippedTestError;

/**
 * Tests Raven and Security Kit modules.
 *
 * @group raven
 * @requires module seckit
 */
class SecKitTest extends BrowserTestBase {

  use StringTranslationTrait;

  /**
   * Additional module to enable.
   */
  const MODULE = 'seckit';

  /**
   * {@inheritdoc}
   */
  protected $defaultTheme = 'stark';

  /**
   * {@inheritdoc}
   */
  protected static $modules = ['raven'];

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    // @fixme The following three lines can be removed if/when module is
    // restored as test dependency.
    if (!isset($this->container->get('extension.list.module')->reset()->getList()[static::MODULE])) {
      throw new SkippedTestError('Required Drupal module: ' . static::MODULE);
    }
    $this->container->get('module_installer')->install([static::MODULE]);
  }

  /**
   * Tests Sentry browser client configuration UI.
   */
  public function testRavenJavascriptConfig(): void {
    $admin_user = $this->drupalCreateUser([
      'administer site configuration',
      'send javascript errors to sentry',
      'administer seckit',
    ]);

    $this->drupalLogin($admin_user);

    $this->drupalGet('admin/config/development/logging');
    $this->submitForm([
      'raven[js][javascript_error_handler]' => TRUE,
      'raven[js][public_dsn]' => 'https://a@domain.test/1',
      'raven[js][seckit_set_report_uri]' => TRUE,
    ], $this->t('Save configuration'));

    $this->drupalGet('admin/config/system/seckit');
    $this->submitForm([
      'seckit_xss[csp][checkbox]' => '1',
      'seckit_xss[csp][report-only]' => '1',
    ], $this->t('Save configuration'));
    $this->assertSession()->responseHeaderEquals('Content-Security-Policy-Report-Only', "report-uri https://domain.test/api/1/security/?sentry_key=a");

    $this->drupalGet('admin/config/system/seckit');
    $this->submitForm([
      'seckit_xss[csp][default-src]' => "'self'",
    ], $this->t('Save configuration'));
    $this->assertSession()->responseHeaderEquals('Content-Security-Policy-Report-Only', "default-src 'self'; connect-src 'self' https://domain.test/api/1/store/ https://domain.test/api/1/envelope/; report-uri https://domain.test/api/1/security/?sentry_key=a");
  }

}
